=============
 Nitime news
=============

February 7th, 2016: version 0.6 released

June 13, 2014: version 0.5 released.

June 19 2012: Version 0.4 released.

August 13 2011: Version 0.3 released. 

November 9 2010: Version 0.2 released. 

August 18 2010: Nitime version 0.1 is officially out.

Scipy 2009 conference paper `available <_static/Scipy2009Nitime.pdf>`_
